@@ -10,7 +10,7 @@ from web3 import Web3, exceptions
 from axie_utils.abis import AXIE_ABI
 from axie_utils.utils import (
     get_nonce,
-    RONIN_PROVIDER_FREE,
+    RONIN_PROVIDER,
     AXIE_CONTRACT,
     TIMEOUT_MINS,
     USER_AGENT
@@ -21,7 +21,7 @@ class Transfer:
     def __init__(self, from_acc, from_private, to_acc, axie_id):
         self.w3 = Web3(
             Web3.HTTPProvider(
-                RONIN_PROVIDER_FREE,
+                RONIN_PROVIDER,
                 request_kwargs={"headers": {"content-type": "application/json", "user-agent": USER_AGENT}}))
         self.from_acc = from_acc.replace("ronin:", "0x")
         self.from_private = from_private
@@ -45,7 +45,7 @@ class Transfer:
             "chainId": 2020,
             "gas": 492874,
             "from": Web3.toChecksumAddress(self.from_acc),
-            "gasPrice": self.w3.toWei("0", "gwei"),
+            "gasPrice": self.w3.toWei("1", "gwei"),
             "value": 0,
             "nonce": nonce
         })
@@ -56,8 +56,8 @@ class Transfer:
         )
         # Send raw transaction
         self.w3.eth.send_raw_transaction(signed.rawTransaction)
-        # get transaction hash
-        hash = self.w3.toHex(self.w3.keccak(signed.rawTransaction))
+        # get transaction _hash
+        _hash = self.w3.toHex(self.w3.keccak(signed.rawTransaction))
         # Wait for transaction to finish or timeout
         start_time = datetime.now()
         while True:
@@ -67,7 +67,7 @@ class Transfer:
                 logging.info(f"Important: Transfer {self}, timed out!")
                 break
             try:
-                recepit = self.w3.eth.get_transaction_receipt(hash)
+                recepit = self.w3.eth.get_transaction_receipt(_hash)
                 if recepit["status"] == 1:
                     success = True
                 else:
@@ -78,10 +78,12 @@ class Transfer:
                 # Sleep 10 seconds not to constantly send requests!
                 sleep(10)
         if success:
-            logging.info(f"{self} completed! Hash: {hash} - "
-                         f"Explorer: https://explorer.roninchain.com/tx/{str(hash)}")
+            logging.info(f"{self} completed! Hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            return _hash
         else:
             logging.info(f"{self} failed")
+            return
 
     def __str__(self):
         return (f"Axie Transfer of axie ({self.axie_id}) from account ({self.from_acc.replace('0x', 'ronin:')}) "
@@ -92,14 +94,14 @@ class TrezorTransfer:
     def __init__(self, from_acc, client, bip_path, to_acc, axie_id):
         self.w3 = Web3(
             Web3.HTTPProvider(
-                RONIN_PROVIDER_FREE,
+                RONIN_PROVIDER,
                 request_kwargs={"headers": {"content-type": "application/json", "user-agent": USER_AGENT}}))
         self.from_acc = from_acc.replace("ronin:", "0x")
         self.to_acc = to_acc.replace("ronin:", "0x")
         self.axie_id = axie_id
         self.client = client
         self.bip_path = parse_path(bip_path)
-        self.gwei = self.w3.toWei('0', 'gwei')
+        self.gwei = self.w3.toWei('1', 'gwei')
         self.gas = 250000
 
     def execute(self):
@@ -118,7 +120,7 @@ class TrezorTransfer:
             "chainId": 2020,
             "gas": self.gas,
             "from": Web3.toChecksumAddress(self.from_acc),
-            "gasPrice": self.w3.toWei("0", "gwei"),
+            "gasPrice": self.w3.toWei("1", "gwei"),
             "value": 0,
             "nonce": nonce
         })
@@ -138,8 +140,8 @@ class TrezorTransfer:
         transaction = rlp.encode((nonce, self.gwei, self.gas, to, 0, data) + sig)
         # Send raw transaction
         self.w3.eth.send_raw_transaction(transaction)
-        # Get transaction hash
-        hash = self.w3.toHex(self.w3.keccak(transaction))
+        # Get transaction _hash
+        _hash = self.w3.toHex(self.w3.keccak(transaction))
         # Wait for transaction to finish or timeout
         start_time = datetime.now()
         while True:
@@ -149,7 +151,7 @@ class TrezorTransfer:
                 logging.info(f"Transfer {self}, timed out!")
                 break
             try:
-                recepit = self.w3.eth.get_transaction_receipt(hash)
+                recepit = self.w3.eth.get_transaction_receipt(_hash)
                 if recepit["status"] == 1:
                     success = True
                 else:
@@ -160,10 +162,12 @@ class TrezorTransfer:
                 # Sleep 10 seconds not to constantly send requests!
                 sleep(10)
         if success:
-            logging.info(f"{self} completed! Hash: {hash} - "
-                         f"Explorer: https://explorer.roninchain.com/tx/{str(hash)}")
+            logging.info(f"{self} completed! Hash: {_hash} - "
+                         f"Explorer: https://explorer.roninchain.com/tx/{str(_hash)}")
+            return _hash
         else:
             logging.info(f"{self} failed")
+            return
 
     def __str__(self):
         return (f"Axie Transfer of axie ({self.axie_id}) from account ({self.from_acc.replace('0x', 'ronin:')}) "
